--[[
BaleWrapperColorExtension

Author: 	Ifko[nator]
Date: 		16.01.2021
Version:	1.5
]]

BaleWrapperColorExtension = {};
BaleWrapperColorExtension.modDirectory = g_currentModDirectory;
BaleWrapperColorExtension.vehicleColors = g_vehicleColors;
BaleWrapperColorExtension.addedColors = {};

function BaleWrapperColorExtension:loadMap(name)
	local storeItems = g_storeManager.items;

	for storeItem = 1, #storeItems do
		if storeItems[storeItem] ~= nil then
			if storeItems[storeItem].configurations ~= nil then
				local vehicleXML = loadXMLFile("vehicle", storeItems[storeItem].xmlFilename);

				for _, colorConfiguration in pairs({"wrappingColor", "baseColor"}) do
					if storeItems[storeItem].configurations[colorConfiguration] ~= nil and not Utils.getNoNil(getXMLBool(vehicleXML, "vehicle." .. colorConfiguration .. "Configurations#useDefaultColors"), false) then		
						BaleWrapperColorExtension.addColors(colorConfiguration, vehicleXML, storeItems[storeItem].configurations);
					end;
				end;

				delete(vehicleXML);
			end;
		end;
	end;
end;

function BaleWrapperColorExtension.addColors(colorConfiguration, vehicleXML, configurations)
	local defaultColorIndex = getXMLInt(vehicleXML, "vehicle." .. colorConfiguration .. "Configurations#defaultColorIndex");
	
	local configurationItems = configurations[colorConfiguration];
	
	for i, vehicleColor in pairs(BaleWrapperColorExtension.vehicleColors) do
		local configItem = StoreItemUtil.addConfigurationItem(configurationItems, "", "", 200, 0, false);

		if vehicleColor.r ~= nil and vehicleColor.g ~= nil and vehicleColor.b ~= nil then
			configItem.color = {vehicleColor.r, vehicleColor.g, vehicleColor.b, 1};
		elseif vehicleColor.brandColor ~= nil then
			configItem.color = g_brandColorManager:getBrandColorByName(vehicleColor.brandColor);
		
			if configItem.color == nil then
				configItem.color = {1, 1, 1, 1};
			
				g_logManager:warning("Unable to find brandColor '%s' in g_vehicleColors", vehicleColor.brandColor);
			end
		end
	
		configItem.name = g_i18n:convertText(vehicleColor.name);

		if i == defaultColorIndex then
			configItem.isDefault = true;
			configItem.price = 0;
			configItem.color = g_brandColorManager:getBrandColorByName(vehicleColor.brandColor);
		end
	end;

	if defaultColorIndex == nil then
		local defaultIsDefined = false;

		for _, item in ipairs(configurationItems) do
			if item.isDefault ~= nil and item.isDefault then
				defaultIsDefined = true;
			end
		end

		if not defaultIsDefined and #configurationItems > 0 then
			configurationItems[1].isDefault = true;
			configurationItems[1].price = 0;
		end;
	end;
end;

--## unused but needed functions

function BaleWrapperColorExtension:update(dt)end;
function BaleWrapperColorExtension:deleteMap()end;
function BaleWrapperColorExtension:keyEvent(unicode, sym, modifier, isDown)end;
function BaleWrapperColorExtension:mouseEvent(posX, posY, isDown, isUp, button)end;
function BaleWrapperColorExtension:draw()end;

addModEventListener(BaleWrapperColorExtension);